@@ -596,15 +596,19 @@ gnome_font_face_find_closest_from_pango_font (PangoFont *pfont)
 GnomeFontFace *
 gnome_font_face_find_closest_from_pango_description (const PangoFontDescription *desc)
 {
-	GnomeFontWeight weight;
+	PangoStyle style;
+	PangoWeight weight;
 	gboolean italic;
+	const char *family_name;
 
 	g_return_val_if_fail (desc != NULL, NULL);
 
-	weight = (desc->weight + 49)/ 100;
-	italic = ((desc->style == PANGO_STYLE_OBLIQUE) || (desc->style == PANGO_STYLE_ITALIC));
+	weight = (pango_font_description_get_weight (desc) + 49)/ 100;
+	style = pango_font_description_get_style (desc);
+	italic = ((style == PANGO_STYLE_OBLIQUE) || (style == PANGO_STYLE_ITALIC));
+	family_name = pango_font_description_get_family (desc);
 
-	return gnome_font_face_find_closest_from_weight_slant (desc->family_name, weight, italic);
+	return gnome_font_face_find_closest_from_weight_slant (family_name, weight, italic);
 }
 
 /* This returns GList of (guchar *) */
