@@ -391,15 +391,12 @@ gnome_print_callback_closure_invoke (GnomePrintContext *ctx,
 				     GClosure          *closure)
 {
 	guint  ret;
-	GValue ret_val = {0, };
 
-	bonobo_closure_invoke (closure, &ret_val,
-			       GNOME_TYPE_PRINT_CONTEXT, ctx,
-			       G_TYPE_POINTER, pagedata,
-			       G_TYPE_POINTER, docdata, 0);
-
-	ret = g_value_get_int (&ret_val);
-	g_value_unset (&ret_val);
+	bonobo_closure_invoke (
+		closure, G_TYPE_UINT, &ret,
+		GNOME_TYPE_PRINT_CONTEXT, ctx,
+		G_TYPE_POINTER, pagedata,
+		G_TYPE_POINTER, docdata, 0);
 
 	return ret;
 }
