@@ -24,8 +24,8 @@
  */
 
 #include <string.h>
-#include <parser.h>
-#include <xmlmemory.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 
 #include "gpa-utils.h"
 #include "gpa-value.h"
