@@ -24,7 +24,7 @@
  */
 
 #include <string.h>
-#include <xmlmemory.h>
+#include <libxml/xmlmemory.h>
 #include "gpa-value.h"
 #include "gpa-option.h"
 
